@@ -15,21 +15,38 @@ class PlotType(str, Enum):
     boxplot = 'boxplot'
 
 
-class AbstractPlot(ABC):
+class DocumentPlot():
 
-    def __init__(self, name):
+    def __init__(self, name, df, title=None):
         self.name = name
 
-    @abstractmethod
+        if title:
+            self.title = title
+        else:
+            self.title = name
+
+        self.path = f"{name}.jpeg"
+
+        if df:
+            self.df = df
+
+    def add_to(self, section):
+        self.fig.savefig(self.path)
+        section.add_paragraph(f".{self.title}\n")
+        section.add_paragraph(f"image::{self.name}[{self.title}]\n\n")
+
     def plot(self):
         pass
 
 
-class ScatterPlot(AbstractPlot):
+
+class ScatterPlot(DocumentPlot):
     def __init__(self, name, df, title=None):
-        self.name = name
+
+        DocumentPlot.__init__(self, name, df, title=None)
+
         self.kind = PlotType.timeseries
-        self.df = df
+
 
     def plot(self, x:str, y:str, hue:str=None, size=None, sizes=(2,100), figsize=(15, 5)):
 
@@ -44,16 +61,13 @@ class ScatterPlot(AbstractPlot):
 
         return fig
 
-class ProphetPlot(AbstractPlot):
+class ProphetPlot(DocumentPlot):
     def __init__(self, name, df, title=None):
-        self.name = name
+
+        DocumentPlot.__init__(self, name, df, title=None)
+
         self.kind = PlotType.prophet
-        if title:
-            self.title = title
-        else:
-            self.title = name
-        if df:
-            self.df = df
+
 
     def plot(self, date_column:str, metric_column:str, period=None):
 
@@ -79,12 +93,12 @@ class ProphetPlot(AbstractPlot):
         return fig
 
 
-class BoxPlot(AbstractPlot):
+class BoxPlot(DocumentPlot):
     def __init__(self, name, df, title=None):
-        self.name = name
+
+        DocumentPlot.__init__(self, name, df, title=None)
+
         self.kind = PlotType.boxplot
-        if df:
-            self.df = df
 
     def plot(self, x:str, y:str, hue:str=None, log_scale=False, figsize=(15, 5)):
         fig, ax = plt.subplots(figsize=(15, 5))
